============
Internal API
============

agoras package
--------------

.. automodule:: agoras
    :members:
    :private-members:
    :special-members:

agoras.api submodule
--------------------

.. automodule:: agoras.api
    :members:
    :private-members:
    :special-members:

agoras.core submodule
---------------------

.. automodule:: agoras.core
    :members:
    :private-members:
    :special-members:
